@@ -1,7 +1,7 @@
 """
 Type annotations for sso-admin service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/literals/)
 
 Usage::
 
@@ -192,6 +192,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
